@@ -14,7 +14,7 @@ use XML::RSS::Private::Output::V2_0;
 
 use vars qw($VERSION $AUTOLOAD @ISA $AUTO_ADD);
 
-$VERSION = '1.32';
+$VERSION = '1.34';
 
 $AUTO_ADD = 0;
 
@@ -305,6 +305,7 @@ sub _get_init_default_key_assignments {
         {key => "encode_output", default => 1,},
         {key => "output",        default => "",},
         {key => "encoding",      default => "UTF-8",},
+        {key => "encode_cb",     default => undef(),},
     ];
 }
 
@@ -453,6 +454,17 @@ sub _get_rendering_class {
     }
 }
 
+sub _get_encode_cb_params
+{
+    my $self = shift;
+
+    return 
+        defined($self->{encode_cb}) ?
+            ("encode_cb" => $self->{encode_cb}) :
+            ()
+            ;
+}
+
 sub _get_rendering_obj {
     my ($self, $ver) = @_;
 
@@ -460,6 +472,7 @@ sub _get_rendering_obj {
         {
             main => $self,
             version => $ver,
+            $self->_get_encode_cb_params(),
         }
     );
 }
@@ -1291,11 +1304,16 @@ XML::RSS - creates and updates RSS files
  # or save it to a file
  $rss->save("fm.rdf");
 
- # insert an item into an RSS file and removes the oldest item if
- # there are already 15 items
+ # insert an item into an RSS file and removes the oldest ones if
+ # there are already 15 items or more
  my $rss = new XML::RSS;
  $rss->parsefile("fm.rdf");
- shift(@{$rss->{'items'}}) if (@{$rss->{'items'}} == 15);
+
+ while (@{$rss->{'items'}} >= 15)
+ {
+     pop(@{$rss->{'items'});
+ }
+
  $rss->add_item(title => "MpegTV Player (mtv) 1.0.9.7",
                 link  => "http://freshmeat.net/news/1999/06/21/930003958.html",
                 mode  => 'insert'
@@ -1345,7 +1363,7 @@ output=>$output, stylesheet=>$stylesheet_url)
 Constructor for XML::RSS. It returns a reference to an XML::RSS object.
 You may also pass the RSS version and the XML encoding to use. The default
 B<version> is 1.0. The default B<encoding> is UTF-8. You may also specify
-the B<output> format regarless of the input version. This comes in handy
+the B<output> format regardless of the input version. This comes in handy
 when you want to convert RSS between versions. The XML::RSS modules
 will convert between any of the formats.  If you set <encode_output> XML::RSS
 will make sure to encode any entities in generated RSS.  This is now on by
@@ -1355,6 +1373,17 @@ You can also pass an optional URL to an XSL stylesheet that can be used to
 output an C<<< <?xsl-stylesheet ... ?> >>> meta-tag in the header that will
 allow some browsers to render the RSS file as HTML.
 
+You can also set C<encode_cb> to a reference to a subroutine that will
+encode the output in a custom way. This subroutine accepts two parameters:
+a reference to the C<XML::RSS::Private::Output::Base>-derived object (which
+should normally not concern you) and the text to encode. It should return
+the text to encode. If not set, then the module will encode using its
+custom encoding routine.
+
+Note that in order to encode properly, you need to handle "CDATA" sections
+properly. Look at L<XML::RSS::Private::Output::Base>'s C<_default_encode()>
+method for how to do it properly.
+
 =item add_item (title=>$title, link=>$link, description=>$desc, mode=>$mode)
 
 Adds an item to the XML::RSS object. B<mode> and B<description> are optional.
